@@ -5,7 +5,7 @@ from metrics_layer.core.model.definitions import Definitions
 from metrics_layer.core.model.filter import LiteralValueCriterion
 from metrics_layer.core.model.join import ZenlyticJoinType
 from metrics_layer.core.sql.query_base import MetricsLayerQueryBase
-from metrics_layer.core.sql.query_dialect import query_lookup
+from metrics_layer.core.sql.query_dialect import NullSorting, query_lookup
 
 
 class MetricsLayerMergedQueries(MetricsLayerQueryBase):
@@ -51,7 +51,9 @@ class MetricsLayerMergedQueries(MetricsLayerQueryBase):
                     self._raise_query_error_from_cte(field.id(capitalize_alias=True))
 
                 order = Order.desc if order_clause.get("sort", "asc").lower() == "desc" else Order.asc
-                complete_query = complete_query.orderby(LiteralValue(order_by_alias), order=order)
+                complete_query = complete_query.orderby(
+                    LiteralValue(order_by_alias), order=order, nulls=NullSorting.last
+                )
 
         sql = str(complete_query.limit(self.limit))
         if semicolon:
